@@ -1,6 +1,6 @@
 package SPVM::Sys;
 
-our $VERSION = "0.488";
+our $VERSION = "0.489";
 
 1;
 
@@ -232,21 +232,19 @@ Gets the process number of the running this program. The same as the Perl L<$$|h
 
 =head2 stat
 
-  static method stat : Sys::IO::Stat ($path_or_fd : object of string|Int);
+  static method stat : Sys::IO::Stat ($path : string);
 
-Creates a L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object.
-
-If the type of $path_or_fd is string, And calls the L<stat|SPVM::Sys::IO::Stat/"stat"> method in the L<Sys::IO::Stat|SPVM::Sys::IO::Stat> class.
-
-If the type of $path_or_fd is Int, And calls the L<fstat|SPVM::Sys::IO::Stat/"fstat"> method in the L<Sys::IO::Stat|SPVM::Sys::IO::Stat> class.
+Creates a L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object and calls the L<stat||SPVM::Sys::IO::Stat/"stat"> method in the L<Sys::IO::Stat|SPVM::Sys::IO::Stat> class.
 
 And returns the a L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object.
 
-Exceptions:
+=head2 fstat
 
-$path_or_fd must be defined. Otherwise an exception is thrown.
+  static method fstat : Sys::IO::Stat ($fd : int);
 
-The type of \$path_or_fd must be string or Int. Otherwise an exception is thrown.
+Creates a L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object and calls the L<fstat||SPVM::Sys::IO::Stat/"fstat"> method in the L<Sys::IO::Stat|SPVM::Sys::IO::Stat> class.
+
+And returns the a L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object.
 
 =head2 chdir
 
@@ -619,6 +617,92 @@ Calls the L<chown|SPVM::Sys::IO/"chown"> method in the L<Sys::IO|SPVM::Sys::IO>
 
 If succeed, returns 1.
 
+=head2 fcntl
+
+  static method fcntl : int ($fd : int, $command : int, $command_arg : object of Int|Sys::IO::Flock|object = undef);
+
+Calls the L<fcntl|SPVM::Sys::IO/"fcntl"> method in the L<Sys::IO|SPVM::Sys::IO> class.
+
+=head2 open
+
+  static method open : int ($stream_ref : Sys::IO::FileStream[], $open_mode : string, $file_name : string);
+
+$open_mode is replaced by the following logic.
+
+  if ($open_mode eq "<") {
+    $open_mode = "rb";
+  }
+  elsif ($open_mode eq ">") {
+    $open_mode = "wb";
+  }
+  elsif ($open_mode eq ">>") {
+    $open_mode = "wa";
+  }
+  elsif ($open_mode eq "+<") {
+    $open_mode = "r+b";
+  }
+  elsif ($open_mode eq "+>") {
+    $open_mode = "w+b";
+  }
+  elsif ($open_mode eq "+>>") {
+    $open_mode = "a+b";
+  }
+
+Calls the L<fopen|SPVM::Sys::IO/"fopen"> method in the L<Sys::IO|SPVM::Sys::IO> class.
+
+The return values is set to $stream_ref->[0].
+
+If succeed, returns 1.
+
+Exceptions:
+
+$stream_ref must be defined. Otherwise an exception is thrown.
+
+The length of \$stream_ref must be equal to 1. Otherwise an exception is thrown.
+
+=head2 fdopen
+
+  static method fdopen : int ($stream_ref : Sys::IO::FileStream[], $open_mode : string, $fd : int);
+
+$open_mode is replaced by the following logic.
+
+  if ($open_mode eq "<") {
+    $open_mode = "rb";
+  }
+  elsif ($open_mode eq ">") {
+    $open_mode = "wb";
+  }
+  elsif ($open_mode eq ">>") {
+    $open_mode = "wa";
+  }
+  elsif ($open_mode eq "+<") {
+    $open_mode = "r+b";
+  }
+  elsif ($open_mode eq "+>") {
+    $open_mode = "w+b";
+  }
+  elsif ($open_mode eq "+>>") {
+    $open_mode = "a+b";
+  }
+
+Calls the L<fdopen|SPVM::Sys::IO/"fdopen"> method in the L<Sys::IO|SPVM::Sys::IO> class.
+
+The return values is set to $stream_ref->[0].
+
+If succeed, returns 1.
+
+Exceptions:
+
+$stream_ref must be defined. Otherwise an exception is thrown.
+
+The length of \$stream_ref must be equal to 1. Otherwise an exception is thrown.
+
+=head2 sysopen
+
+  static method sysopen : Sys::IO::FileStream ($fd_ref : int*, $path : string, $flags : int, $mode : int = 0);
+
+Calls the L<open|SPVM::Sys::IO/"open"> method in the L<Sys::IO|SPVM::Sys::IO> class.
+
 =head2 Sys::Env
 
 =head4 L<Sys::Env|SPVM::Sys::Env>
