@@ -1,3 +1,6 @@
+// Copyright (c) 2023 Yuki Kimoto
+// MIT License
+
 #include "spvm_native.h"
 #include "spvm_socket_util.h"
 
@@ -7,12 +10,12 @@ const char* FILE_NAME = "Sys/Socket/In_addr.c";
 
 int32_t SPVM__Sys__Socket__In_addr__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   struct in_addr* address = env->new_memory_stack(env, stack, sizeof(struct in_addr));
 
-  void* obj_address = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In_addr", address, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  void* obj_address = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In_addr", address, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   stack[0].oval = obj_address;
   
