@@ -10,12 +10,12 @@ const char* FILE_NAME = "Sys/Socket/Ip_mreq.c";
 
 int32_t SPVM__Sys__Socket__Ip_mreq__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   struct ip_mreq* multi_request = env->new_memory_stack(env, stack, sizeof(struct ip_mreq));
 
-  void* obj_multi_request = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Ip_mreq", multi_request, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  void* obj_multi_request = env->new_pointer_object_by_name(env, stack, "Sys::Socket::Ip_mreq", multi_request, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   stack[0].oval = obj_multi_request;
   
@@ -39,7 +39,7 @@ int32_t SPVM__Sys__Socket__Ip_mreq__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Socket__Ip_mreq__imr_multiaddr(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_self = stack[0].oval;
   
@@ -50,8 +50,8 @@ int32_t SPVM__Sys__Socket__Ip_mreq__imr_multiaddr(SPVM_ENV* env, SPVM_VALUE* sta
   struct in_addr* address_ret = env->new_memory_stack(env, stack, sizeof(struct in_addr));
   *address_ret = address;
 
-  void* obj_address_ret = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In_addr", address_ret, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  void* obj_address_ret = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In_addr", address_ret, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   stack[0].oval = obj_address_ret;
   
@@ -74,7 +74,7 @@ int32_t SPVM__Sys__Socket__Ip_mreq__set_imr_multiaddr(SPVM_ENV* env, SPVM_VALUE*
 
 int32_t SPVM__Sys__Socket__Ip_mreq__imr_interface(SPVM_ENV* env, SPVM_VALUE* stack) {
   
-  int32_t e = 0;
+  int32_t error_id = 0;
   
   void* obj_self = stack[0].oval;
   
@@ -85,8 +85,8 @@ int32_t SPVM__Sys__Socket__Ip_mreq__imr_interface(SPVM_ENV* env, SPVM_VALUE* sta
   struct in_addr* imr_interface_ret = env->new_memory_stack(env, stack, sizeof(struct in_addr));
   *imr_interface_ret = imr_interface;
 
-  void* obj_imr_interface_ret = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In_addr", imr_interface_ret, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  void* obj_imr_interface_ret = env->new_pointer_object_by_name(env, stack, "Sys::Socket::In_addr", imr_interface_ret, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
   
   stack[0].oval = obj_imr_interface_ret;
   
