@@ -1,3 +1,6 @@
+// Copyright (c) 2023 Yuki Kimoto
+// MIT License
+
 #include "spvm_native.h"
 
 #include <sys/time.h>
@@ -8,12 +11,12 @@ static const char* FILE_NAME = "Sys/Time/Timespec.c";
 
 int32_t SPVM__Sys__Time__Timespec__new(SPVM_ENV* env, SPVM_VALUE* stack) {
 
-  int32_t e;
+  int32_t error_id = 0;
   
   struct timespec* st_tv = env->new_memory_stack(env, stack, sizeof(struct timespec));
   
-  void* obj_tv = env->new_pointer_object_by_name(env, stack, "Sys::Time::Timespec", st_tv, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  void* obj_tv = env->new_pointer_object_by_name(env, stack, "Sys::Time::Timespec", st_tv, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
 
   stack[0].oval = obj_tv;
   
