@@ -9,12 +9,12 @@ static const char* FILE_NAME = "Sys/Time/Tm.c";
 
 int32_t SPVM__Sys__Time__Tm__new(SPVM_ENV* env, SPVM_VALUE* stack) {
 
-  int32_t e;
+  int32_t error_id = 0;
   
   struct tm* st_tm = env->new_memory_stack(env, stack, sizeof(struct tm));
   
-  void* obj_tm = env->new_pointer_object_by_name(env, stack, "Sys::Time::Tm", st_tm, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  void* obj_tm = env->new_pointer_object_by_name(env, stack, "Sys::Time::Tm", st_tm, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
 
   stack[0].oval = obj_tm;
   
